<?php
/**
 * typefocus8 Theme Customizer
 *
 * @package typefocus8
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function typefocus8_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'typefocus8_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function typefocus8_customize_preview_js() {
	wp_enqueue_script( 'typefocus8_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'typefocus8_customize_preview_js' );

/**
 * Author Image addition using customizer
 */
function typefocus8_author_image_customizer( $wp_customize ) {
    $wp_customize->add_section(
        'typefocus8_author_image',
        array(
            'title'     => 'TYPEFOCUS - Author Image',
            'priority'  => 201
        )
    );
    
    // disabling
    $wp_customize->add_setting(
        'typefocus8_author_image_disabled',
        array(
            'default'      => 'false',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_author_image_disabled',
        array(
            'label'    => 'Disable TF author-image',
            'section'  => 'typefocus8_author_image',
            'type'     => 'checkbox',
        )
    );    
    
    $wp_customize->add_setting(
        'typefocus8_author_image',
        array(
            'default'      => '',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Image_Control(
            $wp_customize,
            'typefocus8_author_image',
            array(
                'label'    => 'Author Image',
                'settings' => 'typefocus8_author_image',
                'section'  => 'typefocus8_author_image'
            )
        )
    );
}
add_action( 'customize_register', 'typefocus8_author_image_customizer' );


/**
 * Copyright addition using customizer
 */
function typefocus8_copyright_customizer( $wp_customize ) {
    $wp_customize->add_section(
        'typefocus8_copyright',
        array(
            'title'     => 'TYPEFOCUS - Footer copyright',
            'priority'  => 202
        )
    );
    $wp_customize->add_setting(
        'typefocus8_copyright',
        array(
            'default'      => 'All Rights Reserved',
            'sanitize_callback'  => 'typefocus8_sanitize_copyright',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
            'typefocus8_copyright',
            array(
                'label'    => 'Copyright Message',
                'section'  => 'typefocus8_copyright',
                'type'       => 'text'
            )
    );
}
add_action( 'customize_register', 'typefocus8_copyright_customizer' );
function typefocus8_sanitize_copyright( $input ) {
    return strip_tags( stripslashes( $input ) );
}


/**
 * Header-Social icons using customizer
 */
function typefocus8_social_customizer( $wp_customize ) {
    $wp_customize->add_section(
        'typefocus8_social',
        array(
            'title'     => 'TYPEFOCUS - Social Icons',
            'priority'  => 203
        )
    );
    
    // disabling
    $wp_customize->add_setting(
        'typefocus8_social_disabled',
        array(
            'default'      => 'false',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_social_disabled',
        array(
            'label'    => 'Disable TF social-icons',
            'section'  => 'typefocus8_social',
            'type'     => 'checkbox',
        )
    );
    
    // facebook
    $wp_customize->add_setting(
        'typefocus8_social[tf_facebook]',
        array(
            'default'      => 'http://www.facebook.com',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_social[tf_facebook]',
        array(
            'label'    => 'Facebook URL',
            'section'  => 'typefocus8_social',
            'type'     => 'text',
        )
    );
    
    //twitter
    $wp_customize->add_setting(
        'typefocus8_social[tf_twitter]',
        array(
            'default'      => 'http://www.twitter.com',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_social[tf_twitter]',
        array(
            'label'    => 'Twitter URL',
            'section'  => 'typefocus8_social',
            'type'     => 'text',
        )
    );
    
    //linkedin
    $wp_customize->add_setting(
        'typefocus8_social[tf_linkedin]',
        array(
            'default'      => 'http://www.linkedin.com',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_social[tf_linkedin]',
        array(
            'label'    => 'linkedin URL',
            'section'  => 'typefocus8_social',
            'type'     => 'text',
        )
    );
    
    //github
    $wp_customize->add_setting(
        'typefocus8_social[tf_github]',
        array(
            'default'      => 'http://www.github.com',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_social[tf_github]',
        array(
            'label'    => 'github URL',
            'section'  => 'typefocus8_social',
            'type'     => 'text',
        )
    );
    
    //google-plus
    $wp_customize->add_setting(
        'typefocus8_social[tf_google-plus]',
        array(
            'default'      => 'http://www.google.com',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'typefocus8_social[tf_google-plus]',
        array(
            'label'    => 'google-plus URL',
            'section'  => 'typefocus8_social',
            'type'     => 'text',
        )
    );       
}
add_action( 'customize_register', 'typefocus8_social_customizer' );


/**
 * Disclaimer addition using customizer
 */
function typefocus8_disclaimer_customizer( $wp_customize ) {
    $wp_customize->add_section(
        'typefocus8_disclaimer',
        array(
            'title'     => 'TYPEFOCUS - Disclaimer',
            'priority'  => 202
        )
    );
    $wp_customize->add_setting(
        'typefocus8_disclaimer',
        array(
            'default'      => 'My disclaimer goes here!!',
            'sanitize_callback'  => 'typefocus8_sanitize_disclaimer',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
            'typefocus8_disclaimer',
            array(
                'label'    => 'Disclaimer Message',
                'section'  => 'typefocus8_disclaimer',
                'type'       => 'text'
            )
    );
}
add_action( 'customize_register', 'typefocus8_disclaimer_customizer' );

function typefocus8_sanitize_disclaimer( $input ) {
    return strip_tags( stripslashes( $input ) );
}

/**
 * Colorschemes
 * */
function colorpalette_theme_customizer( $wp_customize ) {

	$wp_customize->add_section( 'colorpalette_color_scheme_settings', array(
		'title'       => __( 'Color Scheme', 'colorpalette' ),
		'priority'    => 30,
		'description' => 'Select your color scheme',
	) );

	$wp_customize->add_setting( 'colorpalette_color_scheme', array(
		'default'        => 'red',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
	) );

	$wp_customize->add_control( 'colorpalette_color_scheme', array(
		'label'   => 'Choose your color scheme',
		'section' => 'colorpalette_color_scheme_settings',
		'default'        => 'red',
		'type'       => 'radio',
		'choices'    => array(
			__( 'red', 'locale' ) => 'red',
			__( 'belize', 'locale' ) => 'belize',			
			__( 'midnight', 'locale' ) => 'midnight',
			__( 'purple', 'locale' ) => 'purple',
 			__( 'pumpkin', 'locale' ) => 'pumpkin',
			__( 'asbestos', 'locale' ) => 'asbestos',                        
		),
	) );
}
add_action('customize_register', 'colorpalette_theme_customizer');

function colorpalette_add_customizer_css() { ?>
	<link rel="stylesheet" href="<?php echo get_template_directory_uri();?>/typefocus-<?php echo strtolower( get_theme_mod( 'colorpalette_color_scheme' ) ); ?>.css" type="text/css" media="screen">
<?php }
add_action( 'wp_head', 'colorpalette_add_customizer_css' );


function typefocus8_fixed_sidebar( $wp_customize ) {
    $wp_customize->add_section(
        'fixed-sidebar', array(
            'title'     => 'TYPEFOCUS - Fixed Sidebar (Left)',
            'priority'  => 205
        )
    );
    
    // disabling
    $wp_customize->add_setting(
        'fixed-sidebar-enable',
        array(
            'default'      => 'false',
            'sanitize_callback'  => 'esc_url_raw',
            'transport'    => 'postMessage'
        )
    );
    $wp_customize->add_control(
        'fixed-sidebar-enable',
        array(
            'label'    => 'Enable Fixed-Sidebar',
            'section'  => 'fixed-sidebar',
            'type'     => 'checkbox',
        )
    );
}
add_action( 'customize_register', 'typefocus8_fixed_sidebar' );
